summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/kstarssplash.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/kstarssplash.cpp')
-rw-r--r--kstars/kstars/kstarssplash.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kstars/kstars/kstarssplash.cpp b/kstars/kstars/kstarssplash.cpp
index 29198caa..1e704929 100644
--- a/kstars/kstars/kstarssplash.cpp
+++ b/kstars/kstars/kstarssplash.cpp
@@ -17,7 +17,7 @@
#include <tqfile.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <klocale.h>
#include <kapplication.h>
@@ -59,19 +59,19 @@ KStarsSplash::KStarsSplash( TQWidget *parent, const char* name )
pal.setColor( TQPalette::Normal, TQColorGroup::Foreground, TQColor( "White" ) );
pal.setColor( TQPalette::Inactive, TQColorGroup::Foreground, TQColor( "White" ) );
label->setPalette( pal );
- label->tqsetAlignment( AlignHCenter );
+ label->setAlignment( AlignHCenter );
label->setText( i18n( "Welcome to KStars. Please stand by while loading..." ) );
topLayout->addWidget( label );
//initialize the progress message label
- textCurrenttqStatus = new TQLabel( page, "label2" );
- textCurrenttqStatus->setPalette( pal );
- textCurrenttqStatus->tqsetAlignment( AlignHCenter );
- topLayout->addWidget( textCurrenttqStatus );
+ textCurrentStatus = new TQLabel( page, "label2" );
+ textCurrentStatus->setPalette( pal );
+ textCurrentStatus->setAlignment( AlignHCenter );
+ topLayout->addWidget( textCurrentStatus );
topLayout->activate();
disableResize();
- setMessage(TQString()); // force tqrepaint of widget with no text
+ setMessage(TQString()); // force repaint of widget with no text
}
KStarsSplash::~KStarsSplash() {
@@ -80,8 +80,8 @@ KStarsSplash::~KStarsSplash() {
void KStarsSplash::paintEvent( TQPaintEvent* ) {
bitBlt( Banner, 0, 0, splashImage, 0, 0, -1, -1 );
- label->tqrepaint(); // standard text label
- textCurrenttqStatus->tqrepaint(); // status text label
+ label->repaint(); // standard text label
+ textCurrentStatus->repaint(); // status text label
}
void KStarsSplash::closeEvent( TQCloseEvent *e ) {
@@ -90,11 +90,11 @@ void KStarsSplash::closeEvent( TQCloseEvent *e ) {
}
void KStarsSplash::setMessage( TQString s ) {
- textCurrenttqStatus->setText( s );
- tqrepaint(); // tqrepaint splash screen
+ textCurrentStatus->setText( s );
+ repaint(); // repaint splash screen
/**
*Flush all event data. This is needed because events will buffered and
*tqrepaint call will queued in event buffer. With flush all X11 events of
*this application will flushed.
*/
kapp->flush();
@@ -90,11 +90,11 @@ void KStarsSplash::closeEvent( TQCloseEvent *e ) {
/**
*Flush all event data. This is needed because events will buffered and
- *tqrepaint call will queued in event buffer. With flush all X11 events of
+ *repaint call will queued in event buffer. With flush all X11 events of
*this application will flushed.
*/